DiskBufferBuilder

Struct DiskBufferBuilder 

pub struct DiskBufferBuilder<I1, S: State = Empty>
where I1: Into<PathBuf>,
{ /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<I1, S: State> DiskBufferBuilder<I1, S>
where I1: Into<PathBuf>,

pub fn build(self) -> Result<SegmentWriter<Disk>>
where S: IsComplete,

Finishes building and performs the requested action.

pub fn base_path(self, value: I1) -> DiskBufferBuilder<I1, SetBasePath<S>>
where S::BasePath: IsUnset,

Required.

pub fn max_file_size( self, value: u64, ) -> DiskBufferBuilder<I1, SetMaxFileSize<S>>
where S::MaxFileSize: IsUnset,

Optional (Some / Option setters). Per-file rotation threshold in bytes. Defaults to min(100 MiB, max_total_size / 4) when not set.

pub fn maybe_max_file_size( self, value: Option<u64>, ) -> DiskBufferBuilder<I1, SetMaxFileSize<S>>
where S::MaxFileSize: IsUnset,

Optional (Some / Option setters). Per-file rotation threshold in bytes. Defaults to min(100 MiB, max_total_size / 4) when not set.

pub fn max_total_size( self, value: u64, ) -> DiskBufferBuilder<I1, SetMaxTotalSize<S>>
where S::MaxTotalSize: IsUnset,

Required.

pub fn rotation_period( self, value: Duration, ) -> DiskBufferBuilder<I1, SetRotationPeriod<S>>
where S::RotationPeriod: IsUnset,

Optional (Some / Option setters). How often to rotate, measured in monotonic time since the writer (or the previous rotation) started. Defaults to 60 seconds. Duration::MAX disables time-based rotation.

pub fn maybe_rotation_period( self, value: Option<Duration>, ) -> DiskBufferBuilder<I1, SetRotationPeriod<S>>
where S::RotationPeriod: IsUnset,

Optional (Some / Option setters). How often to rotate, measured in monotonic time since the writer (or the previous rotation) started. Defaults to 60 seconds. Duration::MAX disables time-based rotation.

pub fn segment_metadata( self, value: Vec<(String, String)>, ) -> DiskBufferBuilder<I1, SetSegmentMetadata<S>>
where S::SegmentMetadata: IsUnset,

Optional (Some / Option setters).

pub fn maybe_segment_metadata( self, value: Option<Vec<(String, String)>>, ) -> DiskBufferBuilder<I1, SetSegmentMetadata<S>>
where S::SegmentMetadata: IsUnset,

Optional (Some / Option setters).