pub struct DumpFuture { /* private fields */ }Available on crate feature
pipeline only.Expand description
Future resolving to the dump’s DumpReceipt.
For a look-back-only dump it resolves once the last captured segment finishes the pipeline; for a dump with a look-forward it resolves after the forward deadline elapses and the last in-window segment finishes.