ProcessErrorKind

Enum ProcessErrorKind 

#[non_exhaustive]
pub enum ProcessErrorKind {
#[non_exhaustive]
Io(Error),
#[non_exhaustive]
Transfer { source: Box<dyn Error + Send + Sync>, retryable: bool, }, }
Available on crate feature pipeline only.
Kind of failure reported by a SegmentProcessor.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


#[non_exhaustive]
Io(Error)

The processor hit an std::io::Error.



#[non_exhaustive]
Transfer

An error transferring data off the host.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
source: Box<dyn Error + Send + Sync>

Underlying error source.

retryable: bool

Whether this error is transient and the segment should be kept on disk for retry.

Implementations

Source

impl ProcessErrorKind

pub fn transfer(source: Box<dyn Error + Send + Sync>, retryable: bool) -> Self

Build a transfer error from an arbitrary source. Used by upload processors that classify their own retryability.

pub fn already_deleted(&self) -> bool

True when the underlying error is “not found”, meaning the segment was already deleted.

pub fn retryable(&self) -> bool

Whether this error is transient and the segment should be kept on disk for retry.